/****************************************************************************
** Meta object code from reading C++ file 'dbus_interface.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kchmviewer-7.7/src/dbus_interface.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbus_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_DBusInterface_t {
    QByteArrayData data[13];
    char stringdata0[146];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DBusInterface_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DBusInterface_t qt_meta_stringdata_DBusInterface = {
    {
QT_MOC_LITERAL(0, 0, 13), // "DBusInterface"
QT_MOC_LITERAL(1, 14, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 30, 26), // "net.kchmviewer.application"
QT_MOC_LITERAL(3, 57, 12), // "loadHelpFile"
QT_MOC_LITERAL(4, 70, 0), // ""
QT_MOC_LITERAL(5, 71, 8), // "filename"
QT_MOC_LITERAL(6, 80, 3), // "url"
QT_MOC_LITERAL(7, 84, 8), // "openPage"
QT_MOC_LITERAL(8, 93, 14), // "guiFindInIndex"
QT_MOC_LITERAL(9, 108, 4), // "word"
QT_MOC_LITERAL(10, 113, 14), // "guiSearchQuery"
QT_MOC_LITERAL(11, 128, 5), // "query"
QT_MOC_LITERAL(12, 134, 11) // "searchQuery"

    },
    "DBusInterface\0D-Bus Interface\0"
    "net.kchmviewer.application\0loadHelpFile\0"
    "\0filename\0url\0openPage\0guiFindInIndex\0"
    "word\0guiSearchQuery\0query\0searchQuery"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DBusInterface[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
       5,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,

 // slots: name, argc, parameters, tag, flags
       3,    2,   41,    4, 0x4a /* Public | isScriptable */,
       7,    1,   46,    4, 0x4a /* Public | isScriptable */,
       8,    1,   49,    4, 0x4a /* Public | isScriptable */,
      10,    1,   52,    4, 0x4a /* Public | isScriptable */,
      12,    1,   55,    4, 0x4a /* Public | isScriptable */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,    6,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::QStringList, QMetaType::QString,   11,

       0        // eod
};

void DBusInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DBusInterface *_t = static_cast<DBusInterface *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->loadHelpFile((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: _t->openPage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->guiFindInIndex((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->guiSearchQuery((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: { QStringList _r = _t->searchQuery((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = _r; }  break;
        default: ;
        }
    }
}

const QMetaObject DBusInterface::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_DBusInterface.data,
      qt_meta_data_DBusInterface,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *DBusInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_DBusInterface.stringdata0))
        return static_cast<void*>(const_cast< DBusInterface*>(this));
    return QObject::qt_metacast(_clname);
}

int DBusInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
